@@ -387,7 +387,7 @@ void _g_file_replace_async(GFile* this, char* arg0, int arg1, GFileCreateFlags a
 		g_file_replace_async(this, arg0, arg1, arg2, arg3, arg4, 0, 0);
 	}
 }
-void _g_file_replace_contents_async(GFile* this, uint8_t* arg0, uint64_t arg1, char* arg2, int arg3, GFileCreateFlags arg4, GCancellable* arg5, void* gofunc) {
+void _g_file_replace_contents_async(GFile* this, uint8_t* arg0, uint32_t arg1, char* arg2, int arg3, GFileCreateFlags arg4, GCancellable* arg5, void* gofunc) {
 	if (gofunc) {
 		g_file_replace_contents_async(this, arg0, arg1, arg2, arg3, arg4, arg5, _GAsyncReadyCallback_c_wrapper_once, gofunc);
 	} else {
@@ -506,28 +506,28 @@ void _g_input_stream_close_async(GInputStream* this, int32_t arg0, GCancellable*
 		g_input_stream_close_async(this, arg0, arg1, 0, 0);
 	}
 }
-void _g_input_stream_read_all_async(GInputStream* this, uint8_t* arg0, uint64_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
+void _g_input_stream_read_all_async(GInputStream* this, uint8_t* arg0, uint32_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
 	if (gofunc) {
 		g_input_stream_read_all_async(this, arg0, arg1, arg2, arg3, _GAsyncReadyCallback_c_wrapper_once, gofunc);
 	} else {
 		g_input_stream_read_all_async(this, arg0, arg1, arg2, arg3, 0, 0);
 	}
 }
-void _g_input_stream_read_async(GInputStream* this, uint8_t* arg0, uint64_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
+void _g_input_stream_read_async(GInputStream* this, uint8_t* arg0, uint32_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
 	if (gofunc) {
 		g_input_stream_read_async(this, arg0, arg1, arg2, arg3, _GAsyncReadyCallback_c_wrapper_once, gofunc);
 	} else {
 		g_input_stream_read_async(this, arg0, arg1, arg2, arg3, 0, 0);
 	}
 }
-void _g_input_stream_read_bytes_async(GInputStream* this, uint64_t arg0, int32_t arg1, GCancellable* arg2, void* gofunc) {
+void _g_input_stream_read_bytes_async(GInputStream* this, uint32_t arg0, int32_t arg1, GCancellable* arg2, void* gofunc) {
 	if (gofunc) {
 		g_input_stream_read_bytes_async(this, arg0, arg1, arg2, _GAsyncReadyCallback_c_wrapper_once, gofunc);
 	} else {
 		g_input_stream_read_bytes_async(this, arg0, arg1, arg2, 0, 0);
 	}
 }
-void _g_input_stream_skip_async(GInputStream* this, uint64_t arg0, int32_t arg1, GCancellable* arg2, void* gofunc) {
+void _g_input_stream_skip_async(GInputStream* this, uint32_t arg0, int32_t arg1, GCancellable* arg2, void* gofunc) {
 	if (gofunc) {
 		g_input_stream_skip_async(this, arg0, arg1, arg2, _GAsyncReadyCallback_c_wrapper_once, gofunc);
 	} else {
@@ -597,14 +597,14 @@ void _g_output_stream_splice_async(GOutputStream* this, GInputStream* arg0, GOut
 		g_output_stream_splice_async(this, arg0, arg1, arg2, arg3, 0, 0);
 	}
 }
-void _g_output_stream_write_all_async(GOutputStream* this, uint8_t* arg0, uint64_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
+void _g_output_stream_write_all_async(GOutputStream* this, uint8_t* arg0, uint32_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
 	if (gofunc) {
 		g_output_stream_write_all_async(this, arg0, arg1, arg2, arg3, _GAsyncReadyCallback_c_wrapper_once, gofunc);
 	} else {
 		g_output_stream_write_all_async(this, arg0, arg1, arg2, arg3, 0, 0);
 	}
 }
-void _g_output_stream_write_async(GOutputStream* this, uint8_t* arg0, uint64_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
+void _g_output_stream_write_async(GOutputStream* this, uint8_t* arg0, uint32_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
 	if (gofunc) {
 		g_output_stream_write_async(this, arg0, arg1, arg2, arg3, _GAsyncReadyCallback_c_wrapper_once, gofunc);
 	} else {
@@ -618,6 +618,20 @@ void _g_output_stream_write_bytes_async(GOutputStream* this, GBytes* arg0, int32
 		g_output_stream_write_bytes_async(this, arg0, arg1, arg2, 0, 0);
 	}
 }
+void _g_output_stream_writev_all_async(GOutputStream* this, GOutputVector* arg0, uint32_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
+	if (gofunc) {
+		g_output_stream_writev_all_async(this, arg0, arg1, arg2, arg3, _GAsyncReadyCallback_c_wrapper_once, gofunc);
+	} else {
+		g_output_stream_writev_all_async(this, arg0, arg1, arg2, arg3, 0, 0);
+	}
+}
+void _g_output_stream_writev_async(GOutputStream* this, GOutputVector* arg0, uint32_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
+	if (gofunc) {
+		g_output_stream_writev_async(this, arg0, arg1, arg2, arg3, _GAsyncReadyCallback_c_wrapper_once, gofunc);
+	} else {
+		g_output_stream_writev_async(this, arg0, arg1, arg2, arg3, 0, 0);
+	}
+}
 void _g_permission_acquire_async(GPermission* this, GCancellable* arg0, void* gofunc) {
 	if (gofunc) {
 		g_permission_acquire_async(this, arg0, _GAsyncReadyCallback_c_wrapper_once, gofunc);
