@@ -12,132 +12,6 @@ static unsigned int _array_length(void* _array)
 	return i;
 }
 
-typedef void* GBaseFinalizeFunc;
-typedef void* GBaseInitFunc;
-typedef struct _GBinding GBinding;
-typedef uint32_t GBindingFlags;
-typedef void* GBindingTransformFunc;
-typedef void* GBoxedCopyFunc;
-typedef void* GBoxedFreeFunc;
-typedef struct _GCClosure GCClosure;
-struct _GCClosure { uint8_t _data[56]; };
-typedef void* GCallback;
-typedef void* GClassFinalizeFunc;
-typedef void* GClassInitFunc;
-typedef struct _GClosure GClosure;
-struct _GClosure { uint8_t _data[52]; };
-typedef void* GClosureMarshal;
-typedef void* GClosureNotify;
-typedef struct _GClosureNotifyData GClosureNotifyData;
-struct _GClosureNotifyData { uint8_t _data[8]; };
-typedef uint32_t GConnectFlags;
-typedef struct _GEnumClass GEnumClass;
-struct _GEnumClass { uint8_t _data[20]; };
-typedef struct _GEnumValue GEnumValue;
-struct _GEnumValue { uint8_t _data[12]; };
-typedef struct _GFlagsClass GFlagsClass;
-struct _GFlagsClass { uint8_t _data[16]; };
-typedef struct _GFlagsValue GFlagsValue;
-struct _GFlagsValue { uint8_t _data[12]; };
-typedef struct _GInitiallyUnowned GInitiallyUnowned;
-typedef struct _GInitiallyUnownedClass GInitiallyUnownedClass;
-struct _GInitiallyUnownedClass { uint8_t _data[68]; };
-typedef void* GInstanceInitFunc;
-typedef void* GInterfaceFinalizeFunc;
-typedef struct _GInterfaceInfo GInterfaceInfo;
-struct _GInterfaceInfo { uint8_t _data[12]; };
-typedef void* GInterfaceInitFunc;
-typedef struct _GObject GObject;
-typedef struct _GObjectClass GObjectClass;
-struct _GObjectClass { uint8_t _data[68]; };
-typedef struct _GObjectConstructParam GObjectConstructParam;
-struct _GObjectConstructParam { uint8_t _data[8]; };
-typedef void* GObjectFinalizeFunc;
-typedef void* GObjectGetPropertyFunc;
-typedef void* GObjectSetPropertyFunc;
-typedef uint32_t GParamFlags;
-typedef struct _GParamSpec GParamSpec;
-typedef struct _GParamSpecBoolean GParamSpecBoolean;
-typedef struct _GParamSpecBoxed GParamSpecBoxed;
-typedef struct _GParamSpecChar GParamSpecChar;
-typedef struct _GParamSpecClass GParamSpecClass;
-struct _GParamSpecClass { uint8_t _data[40]; };
-typedef struct _GParamSpecDouble GParamSpecDouble;
-typedef struct _GParamSpecEnum GParamSpecEnum;
-typedef struct _GParamSpecFlags GParamSpecFlags;
-typedef struct _GParamSpecFloat GParamSpecFloat;
-typedef struct _GParamSpecGType GParamSpecGType;
-typedef struct _GParamSpecInt GParamSpecInt;
-typedef struct _GParamSpecInt64 GParamSpecInt64;
-typedef struct _GParamSpecLong GParamSpecLong;
-typedef struct _GParamSpecObject GParamSpecObject;
-typedef struct _GParamSpecOverride GParamSpecOverride;
-typedef struct _GParamSpecParam GParamSpecParam;
-typedef struct _GParamSpecPointer GParamSpecPointer;
-typedef struct _GParamSpecPool GParamSpecPool;
-struct _GParamSpecPool {};
-typedef struct _GParamSpecString GParamSpecString;
-typedef struct _GParamSpecTypeInfo GParamSpecTypeInfo;
-struct _GParamSpecTypeInfo { uint8_t _data[28]; };
-typedef struct _GParamSpecUChar GParamSpecUChar;
-typedef struct _GParamSpecUInt GParamSpecUInt;
-typedef struct _GParamSpecUInt64 GParamSpecUInt64;
-typedef struct _GParamSpecULong GParamSpecULong;
-typedef struct _GParamSpecUnichar GParamSpecUnichar;
-typedef struct _GParamSpecValueArray GParamSpecValueArray;
-typedef struct _GParamSpecVariant GParamSpecVariant;
-typedef struct _GParameter GParameter;
-struct _GParameter { uint8_t _data[32]; };
-typedef void* GSignalAccumulator;
-typedef void* GSignalEmissionHook;
-typedef uint32_t GSignalFlags;
-typedef struct _GSignalInvocationHint GSignalInvocationHint;
-struct _GSignalInvocationHint { uint8_t _data[12]; };
-typedef uint32_t GSignalMatchType;
-typedef struct _GSignalQuery GSignalQuery;
-struct _GSignalQuery { uint8_t _data[28]; };
-typedef void* GToggleNotify;
-typedef struct _GTypeCValue GTypeCValue;
-struct _GTypeCValue { uint8_t _data[8]; };
-typedef struct _GTypeClass GTypeClass;
-struct _GTypeClass { uint8_t _data[4]; };
-typedef void* GTypeClassCacheFunc;
-typedef uint32_t GTypeDebugFlags;
-typedef uint32_t GTypeFlags;
-typedef uint32_t GTypeFundamentalFlags;
-typedef struct _GTypeFundamentalInfo GTypeFundamentalInfo;
-struct _GTypeFundamentalInfo { uint8_t _data[4]; };
-typedef struct _GTypeInfo GTypeInfo;
-struct _GTypeInfo { uint8_t _data[36]; };
-typedef struct _GTypeInstance GTypeInstance;
-struct _GTypeInstance { uint8_t _data[4]; };
-typedef struct _GTypeInterface GTypeInterface;
-struct _GTypeInterface { uint8_t _data[8]; };
-typedef void* GTypeInterfaceCheckFunc;
-typedef struct _GTypeModule GTypeModule;
-typedef struct _GTypeModuleClass GTypeModuleClass;
-struct _GTypeModuleClass { uint8_t _data[92]; };
-typedef struct _GTypePlugin GTypePlugin;
-typedef struct _GTypePluginClass GTypePluginClass;
-struct _GTypePluginClass { uint8_t _data[24]; };
-typedef void* GTypePluginCompleteInterfaceInfo;
-typedef void* GTypePluginCompleteTypeInfo;
-typedef void* GTypePluginUnuse;
-typedef void* GTypePluginUse;
-typedef struct _GTypeQuery GTypeQuery;
-struct _GTypeQuery { uint8_t _data[16]; };
-typedef struct _GTypeValueTable GTypeValueTable;
-struct _GTypeValueTable { uint8_t _data[32]; };
-typedef struct _GValue GValue;
-struct _GValue { uint8_t _data[24]; };
-typedef struct _GValueArray GValueArray;
-struct _GValueArray { uint8_t _data[12]; };
-typedef void* GValueTransform;
-typedef void* GWeakNotify;
-typedef struct _GWeakRef GWeakRef;
-struct _GWeakRef {};
-typedef struct _G_Value__data__union G_Value__data__union;
-struct _G_Value__data__union { uint8_t _data[8]; };
 typedef struct _GArray GArray;
 struct _GArray { uint8_t _data[8]; };
 typedef uint32_t GAsciiType;
@@ -390,6 +264,132 @@ typedef uint32_t GVariantParseError;
 typedef struct _GVariantType GVariantType;
 struct _GVariantType {};
 typedef void* GVoidFunc;
+typedef void* GBaseFinalizeFunc;
+typedef void* GBaseInitFunc;
+typedef struct _GBinding GBinding;
+typedef uint32_t GBindingFlags;
+typedef void* GBindingTransformFunc;
+typedef void* GBoxedCopyFunc;
+typedef void* GBoxedFreeFunc;
+typedef struct _GCClosure GCClosure;
+struct _GCClosure { uint8_t _data[56]; };
+typedef void* GCallback;
+typedef void* GClassFinalizeFunc;
+typedef void* GClassInitFunc;
+typedef struct _GClosure GClosure;
+struct _GClosure { uint8_t _data[52]; };
+typedef void* GClosureMarshal;
+typedef void* GClosureNotify;
+typedef struct _GClosureNotifyData GClosureNotifyData;
+struct _GClosureNotifyData { uint8_t _data[8]; };
+typedef uint32_t GConnectFlags;
+typedef struct _GEnumClass GEnumClass;
+struct _GEnumClass { uint8_t _data[20]; };
+typedef struct _GEnumValue GEnumValue;
+struct _GEnumValue { uint8_t _data[12]; };
+typedef struct _GFlagsClass GFlagsClass;
+struct _GFlagsClass { uint8_t _data[16]; };
+typedef struct _GFlagsValue GFlagsValue;
+struct _GFlagsValue { uint8_t _data[12]; };
+typedef struct _GInitiallyUnowned GInitiallyUnowned;
+typedef struct _GInitiallyUnownedClass GInitiallyUnownedClass;
+struct _GInitiallyUnownedClass { uint8_t _data[68]; };
+typedef void* GInstanceInitFunc;
+typedef void* GInterfaceFinalizeFunc;
+typedef struct _GInterfaceInfo GInterfaceInfo;
+struct _GInterfaceInfo { uint8_t _data[12]; };
+typedef void* GInterfaceInitFunc;
+typedef struct _GObject GObject;
+typedef struct _GObjectClass GObjectClass;
+struct _GObjectClass { uint8_t _data[68]; };
+typedef struct _GObjectConstructParam GObjectConstructParam;
+struct _GObjectConstructParam { uint8_t _data[8]; };
+typedef void* GObjectFinalizeFunc;
+typedef void* GObjectGetPropertyFunc;
+typedef void* GObjectSetPropertyFunc;
+typedef uint32_t GParamFlags;
+typedef struct _GParamSpec GParamSpec;
+typedef struct _GParamSpecBoolean GParamSpecBoolean;
+typedef struct _GParamSpecBoxed GParamSpecBoxed;
+typedef struct _GParamSpecChar GParamSpecChar;
+typedef struct _GParamSpecClass GParamSpecClass;
+struct _GParamSpecClass { uint8_t _data[40]; };
+typedef struct _GParamSpecDouble GParamSpecDouble;
+typedef struct _GParamSpecEnum GParamSpecEnum;
+typedef struct _GParamSpecFlags GParamSpecFlags;
+typedef struct _GParamSpecFloat GParamSpecFloat;
+typedef struct _GParamSpecGType GParamSpecGType;
+typedef struct _GParamSpecInt GParamSpecInt;
+typedef struct _GParamSpecInt64 GParamSpecInt64;
+typedef struct _GParamSpecLong GParamSpecLong;
+typedef struct _GParamSpecObject GParamSpecObject;
+typedef struct _GParamSpecOverride GParamSpecOverride;
+typedef struct _GParamSpecParam GParamSpecParam;
+typedef struct _GParamSpecPointer GParamSpecPointer;
+typedef struct _GParamSpecPool GParamSpecPool;
+struct _GParamSpecPool {};
+typedef struct _GParamSpecString GParamSpecString;
+typedef struct _GParamSpecTypeInfo GParamSpecTypeInfo;
+struct _GParamSpecTypeInfo { uint8_t _data[28]; };
+typedef struct _GParamSpecUChar GParamSpecUChar;
+typedef struct _GParamSpecUInt GParamSpecUInt;
+typedef struct _GParamSpecUInt64 GParamSpecUInt64;
+typedef struct _GParamSpecULong GParamSpecULong;
+typedef struct _GParamSpecUnichar GParamSpecUnichar;
+typedef struct _GParamSpecValueArray GParamSpecValueArray;
+typedef struct _GParamSpecVariant GParamSpecVariant;
+typedef struct _GParameter GParameter;
+struct _GParameter { uint8_t _data[32]; };
+typedef void* GSignalAccumulator;
+typedef void* GSignalEmissionHook;
+typedef uint32_t GSignalFlags;
+typedef struct _GSignalInvocationHint GSignalInvocationHint;
+struct _GSignalInvocationHint { uint8_t _data[12]; };
+typedef uint32_t GSignalMatchType;
+typedef struct _GSignalQuery GSignalQuery;
+struct _GSignalQuery { uint8_t _data[28]; };
+typedef void* GToggleNotify;
+typedef struct _GTypeCValue GTypeCValue;
+struct _GTypeCValue {};
+typedef struct _GTypeClass GTypeClass;
+struct _GTypeClass { uint8_t _data[4]; };
+typedef void* GTypeClassCacheFunc;
+typedef uint32_t GTypeDebugFlags;
+typedef uint32_t GTypeFlags;
+typedef uint32_t GTypeFundamentalFlags;
+typedef struct _GTypeFundamentalInfo GTypeFundamentalInfo;
+struct _GTypeFundamentalInfo { uint8_t _data[4]; };
+typedef struct _GTypeInfo GTypeInfo;
+struct _GTypeInfo { uint8_t _data[36]; };
+typedef struct _GTypeInstance GTypeInstance;
+struct _GTypeInstance { uint8_t _data[4]; };
+typedef struct _GTypeInterface GTypeInterface;
+struct _GTypeInterface { uint8_t _data[8]; };
+typedef void* GTypeInterfaceCheckFunc;
+typedef struct _GTypeModule GTypeModule;
+typedef struct _GTypeModuleClass GTypeModuleClass;
+struct _GTypeModuleClass { uint8_t _data[92]; };
+typedef struct _GTypePlugin GTypePlugin;
+typedef struct _GTypePluginClass GTypePluginClass;
+struct _GTypePluginClass { uint8_t _data[24]; };
+typedef void* GTypePluginCompleteInterfaceInfo;
+typedef void* GTypePluginCompleteTypeInfo;
+typedef void* GTypePluginUnuse;
+typedef void* GTypePluginUse;
+typedef struct _GTypeQuery GTypeQuery;
+struct _GTypeQuery { uint8_t _data[16]; };
+typedef struct _GTypeValueTable GTypeValueTable;
+struct _GTypeValueTable { uint8_t _data[32]; };
+typedef struct _GValue GValue;
+struct _GValue { uint8_t _data[24]; };
+typedef struct _GValueArray GValueArray;
+struct _GValueArray { uint8_t _data[12]; };
+typedef void* GValueTransform;
+typedef void* GWeakNotify;
+typedef struct _GWeakRef GWeakRef;
+struct _GWeakRef {};
+typedef struct _G_Value__data__union G_Value__data__union;
+struct _G_Value__data__union { uint8_t _data[8]; };
 typedef struct _GUdevClient GUdevClient;
 typedef struct _GUdevClientClass GUdevClientClass;
 typedef struct _GUdevClientPrivate GUdevClientPrivate;
